@@ -1,6 +1,6 @@
 /*
  * Copyright (c) [2014-2015] Novell, Inc.
- * Copyright (c) [2016-2022] SUSE LLC
+ * Copyright (c) [2016-2023] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -349,6 +349,29 @@ namespace storage
     }
 
 
+    bool
+    BlkDevice::Impl::is_alias_of(const string& name) const
+    {
+	struct Link
+	{
+	    const char* prefix;
+	    const vector<string>& variable;
+	};
+
+	const Link links[] = {
+	    { DEV_DISK_BY_PATH_DIR "/", udev_paths },
+	    { DEV_DISK_BY_ID_DIR "/", udev_ids },
+	};
+
+	for (const Link& link : links)
+	    for (const string& tmp : link.variable)
+		if (link.prefix + tmp == name)
+		    return true;
+
+	return false;
+    }
+
+
     bool
     BlkDevice::Impl::exists_by_any_name(const Devicegraph* devicegraph, const string& name,
 					SystemInfo::Impl& system_info)
@@ -361,7 +384,7 @@ namespace storage
 	    const BlkDevice* blk_device = dynamic_cast<const BlkDevice*>(devicegraph->get_impl()[vertex]);
 	    if (blk_device)
 	    {
-		if (blk_device->get_name() == name)
+		if (blk_device->get_name() == name || blk_device->get_impl().is_alias_of(name))
 		    return true;
 	    }
 	}
@@ -401,7 +424,7 @@ namespace storage
 	    BlkDevice* blk_device = dynamic_cast<BlkDevice*>(devicegraph->get_impl()[vertex]);
 	    if (blk_device)
 	    {
-		if (blk_device->get_name() == name)
+		if (blk_device->get_name() == name || blk_device->get_impl().is_alias_of(name))
 		    return blk_device;
 	    }
 	}
@@ -441,7 +464,7 @@ namespace storage
 	    const BlkDevice* blk_device = dynamic_cast<const BlkDevice*>(devicegraph->get_impl()[vertex]);
 	    if (blk_device)
 	    {
-		if (blk_device->get_name() == name)
+		if (blk_device->get_name() == name || blk_device->get_impl().is_alias_of(name))
 		    return blk_device;
 	    }
 	}
@@ -908,18 +931,22 @@ namespace storage
     void
     BlkDevice::Impl::wipe_device() const
     {
-	string cmd_line = WIPEFS_BIN " --all " + quote(get_name());
+	wait_for_devices({ get_non_impl() });
 
-	SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	SystemCmd::Args cmd_args = { WIPEFS_BIN, "--all", get_name() };
+
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
     }
 
 
     void
     BlkDevice::Impl::discard_device() const
     {
-	string cmd_line = BLKDISCARD_BIN " " + quote(get_name());
+	wait_for_devices({ get_non_impl() });
 
-	SystemCmd cmd(cmd_line, SystemCmd::NoThrow);
+	SystemCmd::Args cmd_args = { BLKDISCARD_BIN, "--verbose", get_name() };
+
+	SystemCmd cmd(cmd_args, SystemCmd::NoThrow);
     }
 
 
@@ -933,7 +960,7 @@ namespace storage
     void
     wait_for_devices(const vector<const BlkDevice*>& blk_devices)
     {
-	SystemCmd(UDEVADM_BIN_SETTLE);
+	udev_settle();
 
 	if (Mockup::get_mode() == Mockup::Mode::PLAYBACK)
 	    return;
@@ -980,7 +1007,7 @@ namespace storage
     void
     wait_for_detach_devices(const vector<string>& dev_names)
     {
-	SystemCmd(UDEVADM_BIN_SETTLE);
+	udev_settle();
 
 	if (Mockup::get_mode() == Mockup::Mode::PLAYBACK)
 	    return;
