@@ -1,6 +1,6 @@
 /*
  * Copyright (c) [2014-2015] Novell, Inc.
- * Copyright (c) [2016-2022] SUSE LLC
+ * Copyright (c) [2016-2023] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -21,7 +21,7 @@
  */
 
 
-#include <ctype.h>
+#include <cctype>
 #include <boost/integer/common_factor_rt.hpp>
 #include <boost/algorithm/string.hpp>
 
@@ -68,7 +68,7 @@ namespace storage
 
     // strings must match /proc/mdstat
     const vector<string> EnumTraits<MdLevel>::names({
-	"unknown", "RAID0", "RAID1", "RAID4", "RAID5", "RAID6", "RAID10", "CONTAINER"
+	"unknown", "RAID0", "RAID1", "RAID4", "RAID5", "RAID6", "RAID10", "CONTAINER", "LINEAR"
     });
 
 
@@ -178,6 +178,7 @@ namespace storage
 
 	switch (md_level)
 	{
+	    case MdLevel::LINEAR:
 	    case MdLevel::RAID0:
 		underlying_size = size / number_of_devices;
 		break;
@@ -307,6 +308,7 @@ namespace storage
 	    case MdLevel::UNKNOWN:
 		return { };
 
+	    case MdLevel::LINEAR:
 	    case MdLevel::RAID0:
 	    case MdLevel::RAID1:
 	    case MdLevel::RAID4:
@@ -338,6 +340,14 @@ namespace storage
     }
 
 
+    bool
+    Md::Impl::is_chunk_size_meaningful() const
+    {
+	return md_level == MdLevel::RAID0 || md_level == MdLevel::RAID4 || md_level == MdLevel::RAID5 ||
+	    md_level == MdLevel::RAID6 || md_level == MdLevel::RAID10;
+    }
+
+
     void
     Md::Impl::set_chunk_size(unsigned long chunk_size)
     {
@@ -407,10 +417,10 @@ namespace storage
 	{
 	    case 0:
 	    {
-		SystemCmd cmd(MDADM_BIN " --assemble --scan");
+		SystemCmd cmd({ MDADM_BIN, "--assemble", "--scan" });
 
 		if (cmd.retcode() == 0)
-		    SystemCmd(UDEVADM_BIN_SETTLE);
+		    udev_settle();
 
 		return cmd.retcode() == 0;
 	    }
@@ -426,7 +436,7 @@ namespace storage
 		SystemCmd cmd2(cmd_line2);
 
 		if (cmd2.retcode() == 0)
-		    SystemCmd(UDEVADM_BIN_SETTLE);
+		    udev_settle();
 
 		unlink(filename.c_str());
 
@@ -443,9 +453,9 @@ namespace storage
     {
 	y2mil("deactivate_mds");
 
-	string cmd_line = MDADM_BIN " --stop --scan";
+	SystemCmd::Args cmd_args = { MDADM_BIN, "--stop", "--scan" };
 
-	SystemCmd cmd(cmd_line);
+	SystemCmd cmd(cmd_args);
 
 	return cmd.retcode() == 0;
     }
@@ -850,6 +860,9 @@ namespace storage
     {
 	switch (md_level)
 	{
+	    case MdLevel::LINEAR:
+		return 2;
+
 	    case MdLevel::RAID0:
 		return 2;
 
@@ -884,6 +897,7 @@ namespace storage
     {
 	switch (md_level)
 	{
+	    case MdLevel::LINEAR:
 	    case MdLevel::RAID0:
 		return false;
 
@@ -905,6 +919,7 @@ namespace storage
     {
 	switch (md_level)
 	{
+	    case MdLevel::LINEAR:
 	    case MdLevel::RAID0:
 	    case MdLevel::RAID1:
 		return false;
@@ -1025,6 +1040,14 @@ namespace storage
 
 	switch (md_level)
 	{
+	    case MdLevel::LINEAR:
+		if (number >= 2)
+		{
+		    size = sum;
+		    optimal_io_size = 0;
+		}
+		break;
+
 	    case MdLevel::RAID0:
 		if (number >= 2)
 		{
@@ -1135,42 +1158,42 @@ namespace storage
 	if (journals.size() > 1)
 	    ST_THROW(Exception("only one journal device allowed"));
 
-	string cmd_line = MDADM_BIN " --create " + quote(get_name()) + " --run --level=" +
-	    boost::to_lower_copy(toString(md_level), locale::classic()) + " --metadata=" +
-	    (metadata.empty() ? "1.0" : metadata) + " --homehost=any";
+	SystemCmd::Args cmd_args = { MDADM_BIN, "--create", get_name(), "--run", "--level=" +
+	    boost::to_lower_copy(toString(md_level), locale::classic()), "--metadata=" +
+	    (metadata.empty() ? "1.0" : metadata), "--homehost=any" };
 
 	if ((md_level == MdLevel::RAID1 || md_level == MdLevel::RAID4 ||
 	     md_level == MdLevel::RAID5 || md_level == MdLevel::RAID6 ||
 	     md_level == MdLevel::RAID10) && journals.empty())
-	    cmd_line += " --bitmap=internal";
+	    cmd_args << "--bitmap=internal";
 
 	// mdadm 4.2 bails out if a chunk size is provided for RAID1 (bsc#1205172)
-	if (md_level != MdLevel::RAID1 && chunk_size > 0)
-	    cmd_line += " --chunk=" + to_string(chunk_size / KiB);
+	if (is_chunk_size_meaningful() && chunk_size > 0)
+	    cmd_args << "--chunk=" + to_string(chunk_size / KiB);
 
 	if (md_parity != MdParity::DEFAULT)
-	    cmd_line += " --parity=" + toString(md_parity);
+	    cmd_args << "--parity=" + toString(md_parity);
 
 	if (!uuid.empty())
-	    cmd_line += " --uuid=" + quote(uuid);
+	    cmd_args << "--uuid=" + uuid;
 
-	cmd_line += " --raid-devices=" + to_string(devices.size());
+	cmd_args << "--raid-devices=" + to_string(devices.size());
 
 	if (!spares.empty())
-	    cmd_line += " --spare-devices=" + to_string(spares.size());
+	    cmd_args << "--spare-devices=" + to_string(spares.size());
 
 	for (const pair<const unsigned int, string>& value : devices)
-	    cmd_line += " " + quote(value.second);
+	    cmd_args << value.second;
 
 	for (const pair<const unsigned int, string>& value : spares)
-	    cmd_line += " " + quote(value.second);
+	    cmd_args << value.second;
 
 	if (!journals.empty())
-	    cmd_line += " --write-journal=" + quote(journals.front());
+	    cmd_args << "--write-journal=" + journals.front();
 
 	wait_for_devices(std::as_const(*this).get_blk_devices());
 
-	SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
 
 	if (uuid.empty())
 	{
@@ -1184,9 +1207,9 @@ namespace storage
     {
 	// log some data about the MD RAID that might be useful for debugging
 
-	string cmd_line = CAT_BIN " " PROC_DIR "/mdstat";
+	SystemCmd::Args cmd_args = { CAT_BIN, PROC_DIR "/mdstat" };
 
-	SystemCmd cmd(cmd_line, SystemCmd::NoThrow);
+	SystemCmd cmd(cmd_args, SystemCmd::NoThrow);
     }
 
 
@@ -1212,12 +1235,12 @@ namespace storage
     void
     Md::Impl::do_delete() const
     {
-	string cmd_line = MDADM_BIN " --zero-superblock ";
+	SystemCmd::Args cmd_args = { MDADM_BIN, "--zero-superblock" };
 
 	for (const BlkDevice* blk_device : get_blk_devices())
-	    cmd_line += " " + quote(blk_device->get_name());
+	    cmd_args << blk_device->get_name();
 
-	SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
     }
 
 
@@ -1340,12 +1363,12 @@ namespace storage
     void
     Md::Impl::do_reduce(const BlkDevice* blk_device) const
     {
-	string cmd_line = MDADM_BIN " --remove " + quote(get_name()) + " " + quote(blk_device->get_name());
+	SystemCmd::Args cmd_args = { MDADM_BIN, "--remove", get_name(), blk_device->get_name() };
 
-	SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
 
 	// Thanks to udev "md-raid-assembly.rules" running "parted <disk>
-	// print" readds the device to the md if the signature is still
+	// print" re-adds the device to the md if the signature is still
 	// valid. Thus remove the signature.
 	blk_device->get_impl().wipe_device();
     }
@@ -1356,13 +1379,12 @@ namespace storage
     {
 	const MdUser* md_user = blk_device->get_impl().get_single_out_holder_of_type<const MdUser>();
 
-	string cmd_line = MDADM_BIN;
-	cmd_line += !md_user->is_spare() ? " --add" : " --add-spare";
-	cmd_line += " " + quote(get_name()) + " " + quote(blk_device->get_name());
+	SystemCmd::Args cmd_args = { MDADM_BIN, !md_user->is_spare() ? "--add" : "--add-spare", get_name(),
+	    blk_device->get_name() };
 
 	storage::wait_for_devices({ blk_device });
 
-	SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
     }
 
 
@@ -1388,9 +1410,9 @@ namespace storage
     void
     Md::Impl::do_deactivate() const
     {
-	string cmd_line = MDADM_BIN " --stop " + quote(get_name());
+	SystemCmd::Args cmd_args = { MDADM_BIN, "--stop", get_name() };
 
-	SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
     }
 
 }
