@@ -1,6 +1,6 @@
 /*
  * Copyright (c) [2014-2015] Novell, Inc.
- * Copyright (c) [2016-2022] SUSE LLC
+ * Copyright (c) [2016-2023] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -60,7 +60,7 @@ namespace storage
     const vector<string> EnumTraits<FsType>::names({
 	"unknown", "auto", "reiserfs", "ext2", "ext3", "ext4", "btrfs", "vfat", "xfs", "jfs", "hfs",
 	"ntfs", "swap", "hfsplus", "nfs", "nfs4", "tmpfs", "iso9660", "udf", "nilfs2", "minix",
-	"ntfs-3g", "f2fs", "exfat", "BitLocker", "vboxsf"
+	"ntfs-3g", "f2fs", "exfat", "BitLocker", "vboxsf", "bcachefs"
     });
 
 
@@ -220,8 +220,13 @@ namespace storage
 	if (!joint_entries.empty())
 	{
 	    if (joint_entries.size() > 1)
+	    {
 		y2war("more than one mount point for " << (*this->get_non_impl()));
 
+		for (const JointEntry& tmp : joint_entries)
+		    y2war(tmp.mount_point_path.fullpath(get_storage()->get_rootprefix()));
+	    }
+
 	    // Selecting the most reasonable mount point:
 	    //
 	    // * shortest active mount point from the fstab or
@@ -259,7 +264,7 @@ namespace storage
 
 		if (fstab_entry != filtered_entries.end())
 		{
-		    // There are active entries in /etc/fsbab, so discarding the rest
+		    // There are active entries in /etc/fstab, so discarding the rest
 		    filtered_entries.erase(
 			remove_if(filtered_entries.begin(), filtered_entries.end(),
 			    [](const JointEntry* entry) { return !entry->is_in_etc_fstab(); }
@@ -550,17 +555,17 @@ namespace storage
 	do_pre_mount();
 	wait_for_devices();
 
-	string cmd_line = MOUNT_BIN " -t " + toString(mount_point->get_mount_type());
+	SystemCmd::Args cmd_args = { MOUNT_BIN, "-t", toString(mount_point->get_mount_type()) };
 
 	MountOpts mount_opts = mount_point->get_impl().get_mount_options();
 	if (force_rw)
 	    mount_opts.remove("ro");
 	if (!mount_opts.empty())
-	    cmd_line += " -o " + quote(mount_opts.format());
+	    cmd_args << "-o"  << mount_opts.format();
 
-	cmd_line += " " + quote(get_mount_name()) + " " + quote(real_mount_point);
+	cmd_args << get_mount_name() << real_mount_point;
 
-	SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
 
 	if (mount_point->exists_in_system())
 	    redirect_to_system(mount_point)->set_active(true);
@@ -572,11 +577,11 @@ namespace storage
     {
 	string real_mount_point = mount_point->get_impl().get_rootprefixed_path();
 
-	string cmd_line = UMOUNT_BIN " " + quote(real_mount_point);
+	SystemCmd::Args cmd_args = { UMOUNT_BIN, real_mount_point };
 
 	try
 	{
-	    SystemCmd cmd(cmd_line, SystemCmd::DoThrow);
+	    SystemCmd cmd(cmd_args, SystemCmd::DoThrow);
 	}
 	catch (const Exception& exception)
 	{
@@ -670,9 +675,9 @@ namespace storage
 	mountable->get_impl().do_pre_mount();
 	mountable->get_impl().wait_for_devices();
 
-	tmp_mount.reset(new TmpMount(storage->get_impl().get_tmp_dir().get_fullname(),
-				     "tmp-mount-XXXXXX", mountable->get_impl().get_mount_name(),
-				     read_only, mountable->get_impl().get_mount_options()));
+	tmp_mount = make_unique<TmpMount>(storage->get_impl().get_tmp_dir().get_fullname(),
+					  "tmp-mount-XXXXXX", mountable->get_impl().get_mount_name(),
+					  read_only, mountable->get_impl().get_mount_options());
     }
 
 
