@@ -81,6 +81,7 @@ namespace storage
     class Devicegraph;
     class Actiongraph;
     class Pool;
+    class SystemInfo;
     enum class PtType;
     enum class FsType;
     enum class MountByType;
@@ -103,7 +104,7 @@ namespace storage
 	/**
 	 * Decide whether multipath should be activated.
 	 *
-	 * The looks_like_real_multipath paramter is not reliable.
+	 * The looks_like_real_multipath parameter is not reliable.
 	 */
 	virtual bool multipath(bool looks_like_real_multipath) const = 0;
 
@@ -455,6 +456,10 @@ namespace storage
     public:
 
 	const Environment& get_environment() const;
+
+	/**
+	 * So far only valid after probing.
+	 */
 	const Arch& get_arch() const;
 
 	/**
@@ -637,10 +642,23 @@ namespace storage
 	 * If an error reported via probe_callbacks is not ignored the
 	 * function throws Aborted.
 	 *
+	 * @see probe(SystemInfo& system_info, const ProbeCallbacks* probe_callbacks)
+	 *
 	 * @throw Aborted, Exception
 	 */
 	void probe(const ProbeCallbacks* probe_callbacks = nullptr);
 
+	/**
+	 * Same as probe(const ProbeCallbacks* probe_callbacks) except for the SystemInfo
+	 * parameter.  Useful when after probing additional calls to
+	 * BlkDevice::find_by_any_name() are used.
+	 *
+	 * @see probe(const ProbeCallbacks* probe_callbacks)
+	 *
+	 * @throw Aborted, Exception
+	 */
+	void probe(SystemInfo& system_info, const ProbeCallbacksV3* probe_callbacks = nullptr);
+
 	/**
 	 * The actiongraph must be valid.
 	 *
