@@ -51,12 +51,12 @@ namespace storage
 
 	void parse(const std::vector<string>& lines);
 
-	string device;
+	const string device;
 
 	string bus_id;
 
-	DasdType type;
-	DasdFormat format;
+	DasdType type = DasdType::UNKNOWN;
+	DasdFormat format = DasdFormat::NONE;
 
     };
 
