@@ -54,9 +54,9 @@ namespace storage
 
 	void parse(const vector<string>& lines);
 
-	string device;
+	const string device;
 
-	unsigned long long min_size;
+	unsigned long long min_size = 0;
 
     };
 
