@@ -32,8 +32,13 @@ namespace storage
     }
 
 
-    SystemInfo::~SystemInfo()
+    SystemInfo::~SystemInfo() = default;
+
+
+    const Arch&
+    SystemInfo::get_arch()
     {
+	return get_impl().getArch();
     }
 
 }
